pub trait InstructionContext {
// Required methods
fn data(&self) -> InstructionData;
fn args(&self) -> &[Value];
fn type_of(&self, v: Value) -> Option<Type>;
fn controlling_type(&self) -> Option<Type>;
}Expand description
Exposes the necessary information for understanding a single Cranelift instruction. It would be nice if [InstructionData] contained everything necessary for interpreting the instruction, but Cranelift’s current design requires looking at other structures. A default implementation using a reference to a [DataFlowGraph] is provided in DfgInstructionContext.
Required Methods
fn data(&self) -> InstructionData
fn args(&self) -> &[Value]
fn type_of(&self, v: Value) -> Option<Type>
fn controlling_type(&self) -> Option<Type>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".